﻿//------------------------------------------------------------------------------
//
// TPGPlugin.jsx
//
// Routines required only by the current plugin.
//
// More information available at: http://thephotogeek.com/lightroom/
//
//------------------------------------------------------------------------------
//
// Copyright 2011-2013 Matt Dawson.  All rights reserved.
//
//------------------------------------------------------------------------------


//=========================================
// Constants
//


//=========================================
// Globals
//


//=========================================
// Utility functions
//


//=========================================
// TPGPlugin
//
// Routines required by the current plugin.
//
// Return: TPGPlugin object
//
function TPGPlugin() {
	// member properties

    this.UNKNOWN = -1;
    this.COMPATIBLE = 1;
    this.CAPABLE = 2;
    this.INCOMPATIBLE = 3;


	// member methods

	// Process error raised during Camera Raw Open step
	this.processCROpenError = function(pipe, logFile, e, fileName) {
        var systemInfo = new TPGSystemInfo();
        var errorHelper = new TPGError();
        var errorMessage = "";

        // Standard error message
        errorMessage += "Image " + fileName
            + " failed to open via Camera Raw. Typically this means the "
            + "Camera Raw plugin needs to be updated to support "
            + "a camera model or Lightroom version.\n\n";

        // Check whether upgrading will help
        if (LR_PSE_COMPATIBLE == this.INCOMPATIBLE) {
            errorMessage += "Photoshop Elements version "
                + systemInfo.getApplicationVersion()
                + " is not fully compatible with your version of Lightroom. "
                + "RAW images taken with newer cameras or using newer Lightroom "
                + "Develop controls may not work until Photoshop Elements "
                + "is upgraded to a newer version.\n\n";
        };

        // Explain appropriate Camera Raw upgrade technique
        if (PSE_CR_AUTO_UPDATE) {
            errorMessage += "Please open Photoshop Element's Help menu and "
                + "check for and install program updates using the appropriate "
                + "menu item.";
        } else {
            errorMessage += "Please open Lightroom's File -> Plug-in Manager "
                + "menu item, select the TPG Elemental plugin, and use the "
                + "'Upgrade Camera Raw' button to locate the latest Camera Raw "
                + "update for installation.";
        };

        if (errorHelper.isError(e)) {
            logFile.log(systemInfo.getLogIdentity());
            logFile.log("Line " + e.line + ": " + errorHelper.getLogMessage(e));
            logFile.log("\nError dialog: " + errorMessage);
            pipe.writeError(e);
            alert(errorMessage);
        };
	};

	// Process error raised when using a locked down feature
	this.processLockedDownFeatureError = function(pipe, logFile, e) {
        var errorHelper = new TPGError();
        var systemInfo = new TPGSystemInfo();
        var errorHelper = new TPGError();
        var errorMessage = "";

        // Standard error message
        errorMessage += "Unable to complete this operation as a required "
            + "Photoshop Elements feature is currently unavailable.\n\n";

        // Explain how to get into the correct Editor mode
        if (systemInfo.getApplicationVersion().match(/11\./)) {
            errorMessage += "Photoshop Elements Editor must be in "
                + "Expert mode for this operation to succeed. "
                + "Please change from Quick or Guided mode to Expert mode, "
                + "close any images opened by the current operation, "
                + "then return to Lightroom to attempt the operation again.";
        } else if (systemInfo.getApplicationVersion().match(/10\./)
                || systemInfo.getApplicationVersion().match(/9\./)
                || systemInfo.getApplicationVersion().match(/8\./)
                || systemInfo.getApplicationVersion().match(/7\./)) {
            // Note: PSE 7 uses slightly different terminology, but close enough
            errorMessage += "Photoshop Elements Editor must be in "
                + "Edit (Full) mode for this operation to succeed. "
                + "Please change from a Create or another Edit mode to Edit "
                + "(Full) mode, close any images opened by the current operation, "
                + "then return to Lightroom to attempt the operation again.";
        } else {
            errorMessage += "Please open Lightroom's File -> Plug-in Manager "
                + "menu item, select the TPG Elemental plugin, and use the "
                + "'Plugin F.A.Q.' button to go to the website for possible "
                + "solutions. If none exist the issue can be reported to the "
                + "developer using the Contact link.";
        };

        if (errorHelper.isError(e)) {
            logFile.log(systemInfo.getLogIdentity());
            logFile.log("Line " + e.line + ": " + errorHelper.getLogMessage(e));
            logFile.log("\nError dialog: " + errorMessage);
            pipe.writeError(e);
            alert(errorMessage);
        };
	};
};

//EOF
